% Define the directory containing your brightfield images
imageDir = 'path_to_image_directory';

% List all image files in the directory
imageFiles = dir(fullfile(imageDir, '*.tiff')); % Adjust the file extension as needed

% Initialize a table to store the results
organoidTable = table();

for i = 1:numel(imageFiles)
    % Read the brightfield image with a known scale bar
    img = imread(fullfile(imageDir, imageFiles(i).name));

    % Specify the length of the known scale bar in pixels
    scale_length_pixels = 100; % Adjust this value based on your image

    % Specify the length of the known scale bar in micrometers (or any other desired unit)
    scale_length_micrometers = 500; % Adjust this value based on your image

    % Calculate the conversion factor from pixels to micrometers
    pixels_to_micrometers = scale_length_micrometers / scale_length_pixels;

    % Convert the image to grayscale
    gray_img = rgb2gray(img);

    % Apply a Gaussian filter to reduce noise
    filtered_img = imgaussfilt(gray_img, 2);

    % Perform image thresholding to separate organoids from background
    threshold = graythresh(filtered_img);
    bw_img = imbinarize(filtered_img, threshold);

    % Fill small holes and remove small objects
    bw_img = imfill(bw_img, 'holes');
    bw_img = bwareaopen(bw_img, 100);

    % Perform connected component analysis to segment individual organoids
    cc = bwconncomp(bw_img);
    stats = regionprops(cc, 'Area', 'Centroid', 'MajorAxisLength', 'MinorAxisLength');

    % Initialize arrays to store organoid properties
    areas = [stats.Area];
    centroids = cat(1, stats.Centroid);
    major_axis_lengths = [stats.MajorAxisLength];
    minor_axis_lengths = [stats.MinorAxisLength];

    % Calculate organoid sizes in micrometers based on major and minor axis lengths
    organoid_sizes = (pi * major_axis_lengths .* minor_axis_lengths / 4) * pixels_to_micrometers;

    % Create a table to store the organoid size data
    imageNames = repmat({imageFiles(i).name}, length(organoid_sizes), 1);
    imageTable = table(imageNames, organoid_sizes', 'VariableNames', {'ImageName', 'Size_um'});

    % Concatenate the current image's data to the main table
    organoidTable = [organoidTable; imageTable];

    % Display the segmented organoids on the original image (optional)
    imshow(img);
    hold on;
    for j = 1:length(centroids)
        text(centroids(j, 1), centroids(j, 2), [num2str(organoid_sizes(j)) ' µm'], 'Color', 'r', 'FontSize', 12);
    end
    hold off;
end

% Display the organoid size table
disp('Organoid Size Table:');
disp(organoidTable);

% Save the table to a CSV file
writetable(organoidTable, 'organoid_sizes.csv');
